@@ -20,6 +20,7 @@
 include "config.php";
 include "functions.php";
 $me = $_SERVER['SCRIPT_NAME'];
+if (!$yuiloc) $yuiloc = "http://yui.yahooapis.com/2.6.0/";
 
 ########################### Attachments ###########################
 if ($_GET['do'] == "att") {
@@ -38,11 +39,28 @@ if ($_GET['do'] == "att") {
 <head>
 <title>AGPLMail</title>
 <link rel="stylesheet" type="text/css" href="default.css"></link>
+<!--[if IE ]>
+<link rel="stylesheet" type="text/css" href="default_ie.css"></link>
+<![endif]-->
 <script language="javascript" src="ajax.js"></script>
 <script language="javascript" src="main.js"></script>
 <script language="javascript" src="whizzywig.js"></script>
+
+<!-- YUI Controls for Autocomplete -->
+<link rel="stylesheet" type="text/css" href="<?php echo $yuiloc ?>build/assets/skins/sam/skin.css" />
+<script type="text/javascript" src="<?php echo $yuiloc ?>build/yahoo-dom-event/yahoo-dom-event.js"></script>
+<script type="text/javascript" src="<?php echo $yuiloc ?>build/connection/connection-min.js"></script>
+<script type="text/javascript" src="<?php echo $yuiloc ?>build/animation/animation-min.js"></script>
+<script type="text/javascript" src="<?php echo $yuiloc ?>build/datasource/datasource-min.js"></script>
+<script type="text/javascript" src="<?php echo $yuiloc ?>build/autocomplete/autocomplete-min.js"></script>
+<script type="text/javascript" src="<?php echo $yuiloc ?>build/element/element-beta-min.js"></script>
+<script type="text/javascript" src="<?php echo $yuiloc ?>build/container/container-min.js"></script>
+<script type="text/javascript" src="<?php echo $yuiloc ?>build/menu/menu-min.js"></script>
+<script type="text/javascript" src="<?php echo $yuiloc ?>build/button/button-min.js"></script>
+<script type="text/javascript" src="<?php echo $yuiloc ?>build/editor/editor-min.js"></script>
+
 </head>
-<body>
+<body class=" yui-skin-sam">
 
 <h1>AGPLMail</h1>
 <?php
@@ -144,7 +162,7 @@ elseif ($_GET['do'] == "contacts") {
 		if ($row['address'] != "" && $row['address'] == urldecode($_GET['addr'])) {
 			echo "<tr><form method=\"post\" action=\"index.php?do=contacts\"><td><input name=\"name\"/ value=\"".$row['name']."\"></td><td><input name=\"addr\" value=\"".$row['address']."\"/></td><td><button type=\"submit\">Edit</button></td></from></tr>";
 		} else {
-			echo "<tr><td>".$row['name']."</td><td>".$row['address']."</td><td><a href=\"index.php?do=contacts&addr=".urlencode($row['address'])."\">edit</a></td></tr>";
+			echo "<tr><td>".$row['name']."</td><td><a href=\"?do=new&to=".urlencode($row['name']." ".$row['address'])."\">".$row['address']."</a></td><td><a href=\"index.php?do=contacts&addr=".urlencode($row['address'])."\">edit</a></td></tr>";
 		}
 	}
 	echo "</table>";
@@ -214,8 +232,10 @@ elseif ($_GET['do'] == "send") {
 <?php } #}
 ########################### New Message ###########################
 elseif ($_GET['do'] == "new") {
+	$to = "";
+	if ($_GET['to']) $to = $_GET['to']; 
 	echo "<h2>New Email</h2>";
-	echo enewtext("","","","","");
+	echo enewtext($to,"","","","");
 }
 ########################### View Message ###########################
 elseif ($_GET['do'] == "message") {
@@ -246,7 +266,19 @@ function moreacts(vaule,tagname) {
 	echo "<a href=\"$me?do=list\">&laquo; Back to ".nice_view($view)."</a> ".actions()."<br />";
 	if ($result = mysql_query("SELECT uid,saved,expanded FROM `".$db_prefix."mess` WHERE convo=$convo AND account='$user' ORDER BY pos",$con)); else die(mysql_error());
 	$first = true;
-	while ($row = mysql_fetch_assoc($result)) {
+	$last = false;
+	$oldrow = mysql_fetch_assoc($result);
+	function get_row() {
+		global $row; global $result; global $oldrow;  global $last; global $first;
+		$row = $oldrow;
+		if ($oldrow = mysql_fetch_assoc($result)) {
+		} else {
+			$last = true;
+		}
+		if ($first);
+		return true;
+	}
+	while (get_row()) {
 		if ($first) {
 			echo "<h2>".$header->subject."</h2>";
 			$first = false;
@@ -269,7 +301,7 @@ function moreacts(vaule,tagname) {
 			$unseen = $header->Unseen;
 		}
 		
-		if ($unseen == "U" || $row['expanded']) {	
+		if (( $unseen == "U" || $row['expanded'] || ($last && $row['expanded'] !== '0') ) && $exall !== 0 || $exall == 1) {	
 			if ($row['saved'] != 1) {
 				$body = "";
 				$struct = imap_fetchstructure($mbox,$msgno);
@@ -297,11 +329,6 @@ function moreacts(vaule,tagname) {
 					}
 					if ($mode == "PLAIN") $body = nice_plain($body);
 				}
-				if (sizeof($att) > 0) $body .= "<br/><br/><h3>Attatchments</h3>";
-				foreach ($att as $anatt) {
-					if ($anatt['type'] == 5) $body .= "<img src=\"".$anatt['link']."\"/><br/>";
-					$body.= "<a href=\"".$anatt['link']."&down=1&name=".$anatt['name']."\">".$anatt['name']."</a><br/><br/>";
-				}
 				#$body .= "<br/><br/><br/>".nl2br(htmlspecialchars(imap_body($mbox, $msgno)));
 			}
 			
@@ -313,7 +340,13 @@ function moreacts(vaule,tagname) {
 			echo "Date: ".date("j F Y H:i",$timestamp)."<br/>";
 			echo "Subject: ".decode_qprint($header->subject)."</div><br/>";
 			#print_r($struct);
-			echo "<div class=\"econ\">".$body."</div>"; ?>
+			echo "<div class=\"econ\">".$body;
+			if (sizeof($att) > 0) echo "<br/><br/><h3>Attatchments</h3>";
+			foreach ($att as $anatt) {
+				if ($anatt['type'] == 5) echo "<img src=\"".$anatt['link']."\"/><br/>";
+				echo "<a href=\"".$anatt['link']."&down=1&name=".$anatt['name']."\">".$anatt['name']."</a><br/><br/>";
+			}
+			echo "</div>"; ?>
 <br/><div class="efoot"><a href="index.php?do=message&convo=<?php echo $convo."&reply=".$row['uid']; ?>#esend">Reply</a> Reply to All Forward</div><?php 
 	if ($_GET['reply'] == $row['uid']) {
 		echo "<div id=\"esend\">".enewtext($header->reply_toaddress,"","",nice_re($header->subject),"On ".date("j F Y H:i",$header->udate).", ".$header->fromaddress." wrote:\n".indent($body),"&convo=$convo")."</div>";
@@ -325,6 +358,7 @@ function moreacts(vaule,tagname) {
 		else {
 			echo "<div class=\"etitle\"><a href=\"?do=message&convo=$convo&expand=".$row['uid']."#mess".$row['uid']."\">".nice_addr_list($header->from)."</a></div>";
 		}	
+		if ($last) break;
 	}
 	// Mark the conversation as read in the sql
 	if (mysql_query("UPDATE `".$db_prefix."convos` SET `read`=1 WHERE account='$user' AND id='$convo'", $con)); else die(mysql_error());
